{% load wagtailcore_tags wagtailimages_tags core_tags %}
  {% include "patterns/basics/images/article-page_variations/article-image.html" %}
  {% include "patterns/basics/headings/article-page_variations/article-heading.html" %}
  {% include "patterns/basics/articles/article-page_variations/article-body.html" %}
  {% include "patterns/basics/articles/related-article-list-with_title-bg.html" %}
